@@ -28,15 +28,12 @@
 
 #include <QtGlobal>
 #include <QObject>
-#include <QSortFilterProxyModel>
-#include <QList>
 #include <QMap>
 #include <QVariant>
 #include <QString>
 #include <QUrl>
 #include <QDateTime>
 #include <QSettings>
-#include <QtDebug>
 
 #include "core/logging.h"
 
@@ -58,6 +55,7 @@
 
 #include "collection/collectionbackend.h"
 #include "playlist/playlist.h"
+#include "playlist/playlistfilter.h"
 #include "playlist/playlistitem.h"
 #include "playlist/playlistmanager.h"
 #include "playlist/playlistsequence.h"
@@ -385,7 +383,7 @@ void Player::NextItem(const Engine::TrackChangeFlags change, const Playlist::Aut
   if (change == Engine::Auto) {
     const PlaylistSequence::RepeatMode repeat_mode = active_playlist->sequence()->repeat_mode();
     if (repeat_mode != PlaylistSequence::Repeat_Off) {
-      if ((repeat_mode == PlaylistSequence::Repeat_Track && nb_errors_received_ >= 3) || (nb_errors_received_ >= app_->playlist_manager()->active()->proxy()->rowCount())) {
+      if ((repeat_mode == PlaylistSequence::Repeat_Track && nb_errors_received_ >= 3) || (nb_errors_received_ >= app_->playlist_manager()->active()->filter()->rowCount())) {
         // We received too many "Error" state changes: probably looping over a playlist which contains only unavailable elements: stop now.
         nb_errors_received_ = 0;
         Stop();
@@ -448,7 +446,7 @@ void Player::PlayPlaylistInternal(const Engine::TrackChangeFlags change, const P
 bool Player::HandleStopAfter(const Playlist::AutoScroll autoscroll) {
 
   if (app_->playlist_manager()->active()->stop_after_current()) {
-    // Find what the next track would've been, and mark that one as current so it plays next time the user presses Play.
+    // Find what the next track would've been, and mark that one as current, so it plays next time the user presses Play.
     const int next_row = app_->playlist_manager()->active()->next_row();
     if (next_row != -1) {
       app_->playlist_manager()->active()->set_current_row(next_row, autoscroll, true);
@@ -624,7 +622,7 @@ void Player::EngineStateChanged(const Engine::State state) {
       break;
     case Engine::Error:
       emit Error();
-      // fallthrough
+      [[fallthrough]];
     case Engine::Empty:
     case Engine::Idle:
       pause_time_ = QDateTime();
@@ -843,7 +841,7 @@ void Player::TrackAboutToEnd() {
   if (engine_->is_autocrossfade_enabled()) {
     // Crossfade is on, so just start playing the next track.  The current one will fade out, and the new one will fade in
 
-    // But, if there's no next track and we don't want to fade out, then do nothing and just let the track finish to completion.
+    // But, if there's no next track, and we don't want to fade out, then do nothing and just let the track finish to completion.
     if (!engine_->is_fadeout_enabled() && !has_next_row) return;
 
     // If the next track is on the same album (or same cue file),
@@ -854,7 +852,7 @@ void Player::TrackAboutToEnd() {
     }
   }
 
-  // Crossfade is off, so start preloading the next track so we don't get a gap between songs.
+  // Crossfade is off, so start preloading the next track, so we don't get a gap between songs.
   if (!has_next_row || !next_item) return;
 
   QUrl url = next_item->StreamUrl();
