@@ -23,14 +23,12 @@
 #include <QFileSystemWatcher>
 #include <QString>
 
-#include "core/logging.h"
-
 #include "filesystemwatcherinterface.h"
 #include "qtfslistener.h"
 
 QtFSListener::QtFSListener(QObject *parent) : FileSystemWatcherInterface(parent), watcher_(this) {
 
-  connect(&watcher_, SIGNAL(directoryChanged(const QString&)), SIGNAL(PathChanged(const QString&)));
+  QObject::connect(&watcher_, &QFileSystemWatcher::directoryChanged, this, &QtFSListener::PathChanged);
 
 }
 
