@@ -24,12 +24,10 @@
 
 #include <glib.h>
 #include <glib-object.h>
-#include <gio/gio.h>
 #include <memory>
 #include <algorithm>
 #include <vector>
 #include <cmath>
-#include <string>
 
 #include <gst/gst.h>
 #include <gst/pbutils/pbutils.h>
@@ -42,15 +40,12 @@
 #include <QByteArray>
 #include <QChar>
 #include <QString>
-#include <QStringBuilder>
 #include <QStringList>
 #include <QUrl>
 #include <QTimeLine>
 #include <QEasingCurve>
 #include <QMetaObject>
-#include <QFlags>
 #include <QTimerEvent>
-#include <QtDebug>
 
 #include "core/logging.h"
 #include "core/taskmanager.h"
@@ -734,7 +729,7 @@ QByteArray GstEngine::FixupUrl(const QUrl &url) {
     }
     else {
       // Currently, Gstreamer can't handle input CD devices inside cdda URL.
-      // So we handle them ourselves: we extract the track number and re-create an URL with only cdda:// + the track number (which can be handled by Gstreamer).
+      // So we handle them ourselves: we extract the track number and re-create a URL with only cdda:// + the track number (which can be handled by Gstreamer).
       // We keep the device in mind, and we will set it later using SourceSetupCallback
       QStringList path = url.path().split('/');
       str = QString("cdda://%1").arg(path.takeLast());
