@@ -26,13 +26,10 @@
 #include <utility>
 #include <algorithm>
 #include <functional>
-#include <iterator>
-#include <type_traits>
 #include <unordered_map>
 #include <random>
 #include <chrono>
 
-#include <QtGlobal>
 #include <QObject>
 #include <QCoreApplication>
 #include <QtConcurrent>
@@ -59,7 +56,6 @@
 #include <QMutableListIterator>
 #include <QFlags>
 #include <QSettings>
-#include <QtDebug>
 #include <QTimer>
 
 #include "core/application.h"
@@ -84,7 +80,6 @@
 #include "songloaderinserter.h"
 #include "songmimedata.h"
 #include "songplaylistitem.h"
-#include "tagreadermessages.pb.h"
 
 #include "smartplaylists/playlistgenerator.h"
 #include "smartplaylists/playlistgeneratorinserter.h"
@@ -93,7 +88,6 @@
 #include "internet/internetplaylistitem.h"
 #include "internet/internetsongmimedata.h"
 
-#include "radios/radioservice.h"
 #include "radios/radiomimedata.h"
 #include "radios/radioplaylistitem.h"
 
@@ -120,7 +114,7 @@ const qint64 Playlist::kMaxScrobblePointNsecs = 240LL * kNsecPerSec;
 Playlist::Playlist(PlaylistBackend *backend, TaskManager *task_manager, CollectionBackend *collection, const int id, const QString &special_type, const bool favorite, QObject *parent)
     : QAbstractListModel(parent),
       is_loading_(false),
-      proxy_(new PlaylistFilter(this)),
+      filter_(new PlaylistFilter(this)),
       queue_(new Queue(this, this)),
       timer_save_(new QTimer(this)),
       backend_(backend),
@@ -150,7 +144,7 @@ Playlist::Playlist(PlaylistBackend *backend, TaskManager *task_manager, Collecti
 
   Restore();
 
-  proxy_->setSourceModel(this);
+  filter_->setSourceModel(this);
   queue_->setSourceModel(this);
 
   QObject::connect(queue_, &Queue::rowsAboutToBeRemoved, this, &Playlist::TracksAboutToBeDequeued);
@@ -491,7 +485,7 @@ void Playlist::ShuffleModeChanged(const PlaylistSequence::ShuffleMode mode) {
 bool Playlist::FilterContainsVirtualIndex(const int i) const {
   if (i < 0 || i >= virtual_items_.count()) return false;
 
-  return proxy_->filterAcceptsRow(virtual_items_[i], QModelIndex());
+  return filter_->filterAcceptsRow(virtual_items_[i], QModelIndex());
 }
 
 int Playlist::NextVirtualIndex(int i, const bool ignore_repeat_track) const {
@@ -2013,7 +2007,7 @@ void Playlist::set_sequence(PlaylistSequence *v) {
 
 }
 
-QSortFilterProxyModel *Playlist::proxy() const { return proxy_; }
+PlaylistFilter *Playlist::filter() const { return filter_; }
 
 SongList Playlist::GetAllSongs() const {
 
