@@ -21,7 +21,6 @@
 
 #include "config.h"
 
-#include <memory>
 #include <functional>
 #include <utility>
 
@@ -36,24 +35,17 @@
 #include <QFileInfo>
 #include <QList>
 #include <QSet>
-#include <QVariant>
 #include <QString>
-#include <QStringBuilder>
-#include <QRegularExpression>
 #include <QUrl>
 #include <QAbstractItemModel>
 #include <QScrollBar>
 #include <QSettings>
-#include <QtDebug>
 #include <QMessageBox>
 
 #include "core/application.h"
-#include "core/logging.h"
 #include "core/player.h"
 #include "core/utilities.h"
 #include "collection/collectionbackend.h"
-#include "collection/collectionplaylistitem.h"
-#include "covermanager/albumcoverloaderresult.h"
 #include "covermanager/currentalbumcoverloader.h"
 #include "organize/organizeformat.h"
 #include "settings/playlistsettingspage.h"
@@ -224,7 +216,7 @@ void PlaylistManager::Save(const int id, const QString &filename, const Playlist
     parser_->Save(playlist(id)->GetAllSongs(), filename, path_type);
   }
   else {
-    // Playlist is not in the playlist manager: probably save action was triggered from the left side bar and the playlist isn't loaded.
+    // Playlist is not in the playlist manager: probably save action was triggered from the left sidebar and the playlist isn't loaded.
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     QFuture<SongList> future = QtConcurrent::run(&PlaylistBackend::GetPlaylistSongs, playlist_backend_, id);
 #else
