@@ -17,15 +17,12 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "config.h"
-
 #include "volumeslider.h"
 
 #include <QApplication>
 #include <QWidget>
 #include <QHash>
 #include <QString>
-#include <QStringBuilder>
 #include <QImage>
 #include <QPainter>
 #include <QPainterPath>
@@ -36,7 +33,6 @@
 #include <QPoint>
 #include <QPolygon>
 #include <QRect>
-#include <QVector>
 #include <QMenu>
 #include <QStyle>
 #include <QStyleOption>
@@ -189,13 +185,6 @@ void PrettySlider::slideEvent(QMouseEvent *e) {
 
 }
 
-namespace Amarok {
-namespace ColorScheme {
-extern QColor Background;
-extern QColor Foreground;
-}  // namespace ColorScheme
-}  // namespace Amarok
-
 #if 0
 /** these functions aren't required in our fixed size world, but they may become useful one day **/
 
